sqltriples.Query.CombinedResults

Package sqltriples :: Module Query :: Class CombinedResults |
[show private | hide private]
[frames | no frames]

## Class CombinedResults

Known Subclasses:
  `CombinedTopLevelResults`, `Conjunction`, `Disjunction`

Method Summary
| `get_query(self, index)`
| `get_subquery(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net